==> rank-eval-client-2.11.0-sources.jar: org/opensearch/index/rankeval/RankEvalRequestBuilder.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.index.rankeval;

import org.opensearch.action.ActionRequestBuilder;
import org.opensearch.action.ActionType;
import org.opensearch.client.OpenSearchClient;

public class RankEvalRequestBuilder extends ActionRequestBuilder<RankEvalRequest, RankEvalResponse> {

    public RankEvalRequestBuilder(OpenSearchClient client, ActionType<RankEvalResponse> action, RankEvalRequest request) {
        super(client, action, request);
    }

    @Override
    public RankEvalRequest request() {
        return request;
    }

    public void setRankEvalSpec(RankEvalSpec spec) {
        this.request.setRankEvalSpec(spec);
    }

    public RankEvalSpec getRankEvalSpec() {
        return this.request.getRankEvalSpec();
    }
}

==> rank-eval-client-3.4.0-sources.jar: org/opensearch/index/rankeval/RankEvalRequestBuilder.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 */

/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

package org.opensearch.index.rankeval;

import org.opensearch.action.ActionRequestBuilder;
import org.opensearch.action.ActionType;
import org.opensearch.transport.client.OpenSearchClient;

public class RankEvalRequestBuilder extends ActionRequestBuilder<RankEvalRequest, RankEvalResponse> {

    public RankEvalRequestBuilder(OpenSearchClient client, ActionType<RankEvalResponse> action, RankEvalRequest request) {
        super(client, action, request);
    }

    @Override
    public RankEvalRequest request() {
        return request;
    }

    public void setRankEvalSpec(RankEvalSpec spec) {
        this.request.setRankEvalSpec(spec);
    }

    public RankEvalSpec getRankEvalSpec() {
        return this.request.getRankEvalSpec();
    }
}
